@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2009 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -436,9 +436,8 @@ check_mbox(Mailbox *mbox)
 		mbox->mail_count = mbox->old_mail_count = mbox->new_mail_count = 0;
 		mbox->last_mtime = 0;
 		mbox->last_size = 0;
-		if (_GK.debug_level & DEBUG_MAIL)
-			printf("check_mbox can't stat(%s): %s\n", mbox->path,
-						g_strerror(errno));
+		gkrellm_debug(DEBUG_MAIL, "check_mbox can't stat(%s): %s\n",
+			mbox->path, g_strerror(errno));
 		return FALSE;
 		}
 
@@ -451,9 +450,8 @@ check_mbox(Mailbox *mbox)
 		{
 		if ((f = fopen(mbox->path, "r")) == NULL)
 			{
-			if (_GK.debug_level & DEBUG_MAIL)
-				printf("check_mbox can't fopen(%s): %s\n", mbox->path,
-							g_strerror(errno));
+			gkrellm_debug(DEBUG_MAIL, "check_mbox can't fopen(%s): %s\n",
+				mbox->path, g_strerror(errno));
 			return FALSE;
 			}
 		mbox->mail_count = 0;
