@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2009 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -102,7 +102,7 @@ static gint		client_input_id,
 				client_fd;
 static gboolean	server_alive;
 
-static gchar	server_buf[4097];
+static gchar	server_buf[4097]; /* TODO: Use dynamic receive buffer */
 static gint		buf_index;
 
 static gchar	locale_decimal_point;
@@ -303,12 +303,17 @@ client_disk_line_from_server(gchar *line)
 	{
 	DiskData	*disk = NULL;
 	GList		*list;
-	gchar		name[16], s1[32], s2[32], s3[32];
+	gchar		*name;
+	gchar		s1[32], s2[32], s3[32];
 	guint64		rblk, wblk;
 	gint		n;
 	gboolean	virtual = FALSE;
 
-	n = sscanf(line, "%15s %31s %31s %31s", name, s1, s2, s3);
+	g_assert(line != NULL);
+	name = g_malloc(strlen(line) * sizeof(gchar));
+
+    /* FIXME: Extend client and server to support disks with both name and label */
+	n = sscanf(line, "%s %31s %31s %31s", name, s1, s2, s3);
 	if (n == 4)
 		{
 		if (   gkrellm_client_check_server_version(2, 2, 7)
@@ -328,15 +333,22 @@ client_disk_line_from_server(gchar *line)
 		s1[0] = '\0';
 		}
 	else
+		{
+		g_warning("Invalid disk line received from server: \"%s\"", line);
+		g_free(name);
 		return;
+		}
+
 	for (list = disk_list; list; list = list->next)
 		{
+		/* Search disk in list */
 		disk = (DiskData *) list->data;
 		if (!strcmp(disk->name, name))
 			break;
 		}
 	if (!list)
 		{
+		/* Disk wasn't found, create new disk and add to list */
 		disk = g_new0(DiskData, 1);
 		disk->name = g_strdup(name);
 		if (s1[0])		/* I expect server to send in order */
@@ -345,10 +357,12 @@ client_disk_line_from_server(gchar *line)
 		}
 	if (disk)
 		{
+		/* Assign parsed data to disk */
 		disk->rblk = rblk;
 		disk->wblk = wblk;
 		disk->virtual = virtual;
 		}
+	g_free(name);
 	}
 
 static void
@@ -1562,8 +1576,8 @@ client_send_to_server(gchar *buf)
 #endif
 	if (n < 0 && errno == EPIPE)
 		{
-		if (_GK.debug_level & DEBUG_CLIENT)
-			printf("Write on closed pipe to gkrellmd server.\n");
+		gkrellm_debug(DEBUG_CLIENT, "Write on closed pipe to gkrellmd " \
+			"server, marking server-connection as dead\n");
 		server_alive = FALSE;
 		return FALSE;
 		}
@@ -1619,6 +1633,7 @@ KeyTable	update_table[] =
 
 
 
+/* TODO: Port to GInputStream */
 static gint
 gkrellm_getline(gint fd, gchar *buf, gint len)
 	{
@@ -1648,11 +1663,10 @@ gkrellm_getline(gint fd, gchar *buf, gint len)
 		}
 	if (nread < 0 && errno != EINTR)
 		{
-		fprintf(stderr, "Broken server connection\n");
+		g_warning("Broken server connection\n");
 		exit(0);
 		}
-	if (_GK.debug_level & DEBUG_CLIENT)
-		printf("%s\n", buf);
+	gkrellm_debug(DEBUG_CLIENT, "%s\n", buf);
 	return n;
 	}
 
@@ -1698,9 +1712,11 @@ process_server_line(KeyTable *table, gint table_size, gchar *line)
 static gboolean
 read_server_setup(gint fd)
 	{
-	gchar			buf[256];
+	gchar			buf[4097]; /* TODO: Use dynamic receive buffer */
 	gint			table_size;
 
+	gkrellm_debug(DEBUG_CLIENT, "read_server_setup()\n");
+
 	/* Pre 2.1.6 gkrellmd does not send <decimal_point>, so put a fallback
 	|  locale_sync() here.
 	*/
@@ -1714,8 +1730,8 @@ read_server_setup(gint fd)
 
 	while (1)
 		{
-		rs=gkrellm_getline(fd, buf, sizeof(buf));
-        if(rs<0)
+		rs = gkrellm_getline(fd, buf, sizeof(buf));
+        if (rs < 0)
             return FALSE;
 		if (!strcmp(buf, "</gkrellmd_setup>"))
 			break;
@@ -1732,8 +1748,8 @@ read_server_setup(gint fd)
 	table_size = sizeof(update_table) / sizeof(KeyTable);
 	while (1)
 		{
-		rs=gkrellm_getline(fd, buf, sizeof(buf));
-        if(rs<0)
+		rs = gkrellm_getline(fd, buf, sizeof(buf));
+        if (rs < 0)
             return FALSE;
 		if (!strcmp(buf, "</initial_update>"))
 			break;
@@ -1747,7 +1763,11 @@ void
 gkrellm_client_mode_disconnect(void)
 	{
 	if (client_fd >= 0)
+		{
+		gkrellm_debug(DEBUG_CLIENT, "gkrellm_client_mode_disconnect(); " \
+			"closing connection to server\n");
 		close(client_fd);
+		}
 	client_fd = -1;
 	server_alive = FALSE;
 	gdk_input_remove(client_input_id);
@@ -1764,6 +1784,8 @@ read_server_input(gpointer data, gint fd, GdkInputCondition condition)
 	count = recv(fd, server_buf + buf_index, n, 0);
 	if (count <= 0)
 		{
+		gkrellm_debug(DEBUG_CLIENT, "read_server_input(); recv() " \
+			"returned error, disconnecting from server\n", count);
 		gkrellm_client_mode_disconnect();
 		return;
 		}
@@ -1775,8 +1797,7 @@ read_server_input(gpointer data, gint fd, GdkInputCondition condition)
 	while (*line && (eol = strchr(line, '\n')) != NULL)
 		{
 		*eol = '\0';
-		if (_GK.debug_level & DEBUG_CLIENT)
-			printf("%s\n", line);
+		gkrellm_debug(DEBUG_CLIENT, "%s\n", line);
 		process_server_line(&update_table[0], table_size, line);
 		line = eol + 1;
 		}
@@ -1825,8 +1846,7 @@ gkrellm_connect_to(gchar *server, gint server_port)
 		if ((fd = socket(res->ai_family, res->ai_socktype,
 				res->ai_protocol)) < 0)
 			continue;
-		if (_GK.debug_level & DEBUG_CLIENT)
-			printf("\t[gkrellm_connect_to: (%d,%d,%d) %s:%d]\n",
+		gkrellm_debug(DEBUG_CLIENT, "\t[gkrellm_connect_to: (%d,%d,%d) %s:%d]\n",
 			       res->ai_family, res->ai_socktype,
 			       res->ai_protocol, server, server_port);
 		if (connect(fd, res->ai_addr, res->ai_addrlen) >= 0)
@@ -1840,8 +1860,8 @@ gkrellm_connect_to(gchar *server, gint server_port)
 		}
 	freeaddrinfo(res0);
 #else
-	if (_GK.debug_level & DEBUG_CLIENT)
-		printf("\t[gkrellm_connect_to: %s:%d]\n", server, server_port);
+	gkrellm_debug(DEBUG_CLIENT, "\t[gkrellm_connect_to: %s:%d]\n", server,
+		server_port);
 	addr = gethostbyname(server);
 	if (addr)
 		{
@@ -1854,6 +1874,7 @@ gkrellm_connect_to(gchar *server, gint server_port)
 			s.sin_port = htons(server_port);
 			if (connect(fd, (struct sockaddr *)&s, sizeof (s)) < 0)
 				{
+				gkrellm_debug(DEBUG_CLIENT, "gkrellm_connect_to(); connect() failed\n");
 #ifdef WIN32
 				closesocket(fd);
 #else
@@ -1863,6 +1884,10 @@ gkrellm_connect_to(gchar *server, gint server_port)
 				}
 			}
 		}
+	else
+		{
+		gkrellm_debug(DEBUG_CLIENT, "gkrellm_connect_to(); gethostbyname() failed\n");
+		}
 #endif
 	if (fd < 0)
 		return -1;
