@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2009 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -158,10 +158,11 @@ gboolean gkrellm_sys_disk_init(void);
 void	gkrellm_sys_disk_read_data(void);
 gchar	*gkrellm_sys_disk_name_from_device(gint device_number,
 				gint unit_number, gint *order);
-gint	gkrellm_sys_disk_order_from_name(gchar *name);
+gint	gkrellm_sys_disk_order_from_name(const gchar *name);
 
 void	gkrellm_disk_client_divert(void (*read_func)(),
 			gchar *(*name_from_device_func)(), gint (*order_from_name_func)());
+void    gkrellm_disk_add_by_name(const gchar *name, const gchar *label);
 void	gkrellm_disk_assign_data_by_device(gint device_number,
 				gint unit_number, guint64 r, guint64 w, gboolean virtual);
 void	gkrellm_disk_assign_data_nth(gint n, guint64 r, guint64 w,
