@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2008 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -179,7 +179,7 @@ get_style_from_list(GList *list, gint n)
 		l = list;
 	if (l->data == NULL)
 		{
-		printf("Warning: NULL style returned %d\n", n);
+		g_warning("Warning: NULL style returned %d\n", n);
 		abort();
 		}
 	style = (GkrellmStyle *) l->data;
@@ -283,7 +283,7 @@ get_piximage_from_list(GList *list, gint n)
 		l = list;
 	if (l->data == NULL)
 		{
-		printf("Warning: NULL image returned %d\n", n);
+		g_warning("Warning: NULL image returned %d\n", n);
 		abort();
 		}
 	return (GkrellmPiximage *) l->data;
@@ -1050,7 +1050,7 @@ load_plugins_placement_file(void)
 	gkrellm_free_glist_and_data(&plugins_place_list);
 	path = gkrellm_make_config_file_name(gkrellm_homedir(),
 				PLUGIN_PLACEMENT_FILE);
-	if ((f = fopen(path, "r")) != NULL)
+	if ((f = g_fopen(path, "r")) != NULL)
 		{
 		while ((fgets(buf, sizeof(buf), f)) != NULL)
 			{
@@ -1077,7 +1077,7 @@ save_plugins_placement_file(void)
 		return;
 	path = gkrellm_make_config_file_name(gkrellm_homedir(),
 				PLUGIN_PLACEMENT_FILE);
-	if ((f = fopen(path, "w")) != NULL)
+	if ((f = g_fopen(path, "w")) != NULL)
 		{
 		for (list = plugins_list; list; list = list->next)
 			{
@@ -1111,7 +1111,7 @@ load_plugins_enable_file(void)
 
 	gkrellm_free_glist_and_data(&plugins_enable_list);
 	path = gkrellm_make_config_file_name(gkrellm_homedir(),PLUGIN_ENABLE_FILE);
-	if ((f = fopen(path, "r")) != NULL)
+	if ((f = g_fopen(path, "r")) != NULL)
 		{
 		while ((fgets(buf, sizeof(buf), f)) != NULL)
 			{
@@ -1139,7 +1139,7 @@ save_plugins_enable_file(void)
 		return;
 	path = gkrellm_make_config_file_name(gkrellm_homedir(),
 				PLUGIN_ENABLE_FILE);
-	if ((f = fopen(path, "w")) != NULL)
+	if ((f = g_fopen(path, "w")) != NULL)
 		{
 		for (list = plugins_list; list; list = list->next)
 			{
@@ -1264,6 +1264,28 @@ gkrellm_plugins_load(void)
 	scan_for_plugins(path);
 	g_free(path);
 
+#if defined(WIN32)
+	path = NULL;
+#if GLIB_CHECK_VERSION(2,16,0)
+	gchar *install_path;
+	install_path = g_win32_get_package_installation_directory_of_module(NULL);
+	if (install_path != NULL)
+		{
+		path = g_build_filename(install_path, "lib", "gkrellm2", "plugins", NULL);
+		g_free(install_path);
+		}
+#else
+	// deprecated since glib 2.16.0
+	path = g_win32_get_package_installation_subdirectory(NULL, NULL, "lib/gkrellm2/plugins");
+#endif
+	if (path)
+		{
+		scan_for_plugins(path);
+		g_free(path);
+		}
+#endif
+
+
 #if defined(LOCAL_PLUGINS_DIR)
 	scan_for_plugins(LOCAL_PLUGINS_DIR);
 #endif
