@@ -1,12 +1,13 @@
 /* GKrellM
-|  Copyright (C) 1999-2008 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
+|                2002      Bill Nalen
+|                2007-2010 Stefan Gehn
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Authors:  Bill Wilson    billw@gkrellm.net
+|            Bill Nalen     bill@nalens.com
+|            Stefan Gehn    stefan+gkrellm@srcbox.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  win32.c code is Copyright (C) Bill Nalen    bill@nalens.com
-|                                Stefan Gehn    stefan.gkrellm@srcbox.net
-|
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
 |  under the terms of the GNU General Public License as published by
@@ -41,18 +42,23 @@
 	#include "../win32-plugin.h"
 #endif
 
-#include <largeint.h> // For disk space calculation
 #include <winioctl.h> // For cdrom eject
 #include <iphlpapi.h> // For tcp connection stats
+
 // Following two are for cpu, proc, disk and network stats
 // which are queried via "performance data counters"
 #include <pdh.h>
 #include <pdhmsg.h>
+
 // Following two are used to determine number of logged in users and
 // pagefile usage via NT-APIs
-#include <ntdef.h>
+#include <subauth.h>
 #include <ntsecapi.h>
 
+#if _WIN32_WINNT >= 0x501 // Windows XP or newer
+#include <wtsapi32.h>
+#endif // _WIN32_WINNT >= 0x501
+
 
 // ----------------------------------------------------------------------------
 // Needed to determine pagefile usage
@@ -63,7 +69,7 @@
 #define STATUS_INFO_LENGTH_MISMATCH ((NTSTATUS)0xC0000004L)
 #define SystemPagefileInformation 18
 
-NTSTATUS NTAPI ZwQuerySystemInformation(
+typedef NTSTATUS (NTAPI *pfZwQuerySystemInformation)(
   /*IN*/ UINT SystemInformationClass,
   /*IN OUT*/ VOID *SystemInformation,
   /*IN*/ ULONG SystemInformationLength,
@@ -81,10 +87,12 @@ typedef struct _SYSTEM_PAGEFILE_INFORMATION
 
 
 // ----------------------------------------------------------------------------
-// Structs and typedefs used to determine the number of logged in users.
-// These should be in ntsecapi.h but are missing in MinGW currently.
-// Docs: http://msdn.microsoft.com/en-us/library/aa378290(VS.85).aspx
-
+/* Structs and typedefs used to determine the number of logged in users.
+ * These should be in ntsecapi.h but are missing in MinGW currently, they
+ * are present in the headers provided by mingw-w64.
+ * Docs: http://msdn.microsoft.com/en-us/library/aa378290(VS.85).aspx
+ */ 
+#if defined(__MINGW32__) && !defined(__MINGW64_VERSION_MAJOR)
 typedef struct _SECURITY_LOGON_SESSION_DATA
 	{
 	ULONG Size;
@@ -101,6 +109,7 @@ typedef struct _SECURITY_LOGON_SESSION_DATA
 	LSA_UNICODE_STRING Upn;
 	}
 	SECURITY_LOGON_SESSION_DATA;
+#endif
 
 // Definitions for function pointers (functions resolved manually at runtime)
 typedef NTSTATUS (NTAPI *pfLsaEnumerateLogonSessions)(
@@ -110,6 +119,28 @@ typedef NTSTATUS (NTAPI *pfLsaGetLogonSessionData)(
 typedef NTSTATUS (NTAPI *pfLsaFreeReturnBuffer)(VOID *Buffer);
 
 
+// ----------------------------------------------------------------------------
+// Missing definitions from MinGW iphlpapi.h
+
+typedef struct {
+  DWORD dwState; // one of MIB_TCP_STATE_*
+  IN6_ADDR LocalAddr;
+  DWORD dwLocalScopeId;
+  DWORD dwLocalPort;
+  IN6_ADDR RemoteAddr;
+  DWORD dwRemoteScopeId;
+  DWORD dwRemotePort;
+} MIB_TCP6ROW, *PMIB_TCP6ROW;
+
+typedef struct {
+  DWORD dwNumEntries;
+  MIB_TCP6ROW table[ANY_SIZE];
+} MIB_TCP6TABLE, *PMIB_TCP6TABLE;
+
+typedef DWORD (WINAPI *GetTcp6TableFunc)(PMIB_TCP6TABLE TcpTable,
+	PDWORD SizePointer, BOOL Order);
+
+
 // ----------------------------------------------------------------------------
 // Max len of device names returned by clean_dev_name().
 // Value taken from net.c load_net_config() and disk.c load_disk_config().
@@ -121,6 +152,7 @@ static PDH_HQUERY pdhQueryHandle = NULL;
 
 static const wchar_t* PDHDLL = L"PDH.DLL";
 static const wchar_t* NTDLL = L"NTDLL.DLL";
+static const wchar_t* WTSAPI32 = L"WTSAPI32.DLL";
 
 
 // ----------------------------------------------------------------------------
@@ -130,6 +162,7 @@ static const wchar_t* NTDLL = L"NTDLL.DLL";
 static void gkrellm_sys_cpu_cleanup(void);
 static void gkrellm_sys_disk_cleanup(void);
 static void gkrellm_sys_mem_cleanup(void);
+static void gkrellm_sys_inet_cleanup(void);
 static void gkrellm_sys_net_cleanup(void);
 static void gkrellm_sys_proc_cleanup(void);
 
@@ -393,6 +426,9 @@ void gkrellm_sys_main_init(void)
 	WSADATA wsdata;
 	int err;
 
+	// Remove current working directory from DLL search path
+	SetDllDirectoryW(L"");
+
 	gkrellm_debug(DEBUG_SYSDEP, "Starting Winsock\n");
 	err = WSAStartup(MAKEWORD(1,1), &wsdata);
 	if (err != 0)
@@ -438,6 +474,7 @@ void gkrellm_sys_main_cleanup(void)
 	gkrellm_sys_cpu_cleanup();
 	gkrellm_sys_disk_cleanup();
 	gkrellm_sys_net_cleanup();
+	gkrellm_sys_inet_cleanup();
 	gkrellm_sys_proc_cleanup();
 	gkrellm_sys_mem_cleanup();
 
@@ -652,6 +689,7 @@ gkrellm_sys_sensors_mbm_init(void)
 	hData = gkrellm_sys_sensors_open_shm_helper(MBM_SHM_NAME, MBM_EXE_NAME);
 	if (hData == 0)
 		return FALSE;
+	gkrellm_debug(DEBUG_SYSDEP, "Mapping MBM SHM file\n");
 	pData = (MBMSharedData *)MapViewOfFile(hData, FILE_MAP_READ, 0, 0, 0);
 	if (pData != NULL)
 		{
@@ -675,7 +713,7 @@ gkrellm_sys_sensors_mbm_init(void)
 					gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, /*sensor_path*/NULL,
 						/*id_name*/id_name, /*id*/i, /*iodev*/0,
 						/*inter*/MBM_INTERFACE, /*factor*/1, /*offset*/0,
-						/*vref*/NULL, /*default_label*/pSensor->ssName);
+						/*vref*/NULL, /*default_label*/(gchar *)pSensor->ssName);
 
 		            g_free(id_name);
 					++tempCount;
@@ -686,7 +724,7 @@ gkrellm_sys_sensors_mbm_init(void)
 					gkrellm_sensors_add_sensor(SENSOR_VOLTAGE, /*sensor_path*/NULL,
 						/*id_name*/id_name, /*id*/i, /*iodev*/0,
 						/*inter*/MBM_INTERFACE, /*factor*/1, /*offset*/0,
-						/*vref*/NULL, /*default_label*/pSensor->ssName);
+						/*vref*/NULL, /*default_label*/(gchar *)pSensor->ssName);
 
 		            g_free(id_name);
 					++voltCount;
@@ -697,7 +735,7 @@ gkrellm_sys_sensors_mbm_init(void)
 					gkrellm_sensors_add_sensor(SENSOR_FAN, /*sensor_path*/NULL,
 						/*id_name*/id_name, /*id*/i, /*iodev*/0,
 						/*inter*/MBM_INTERFACE, /*factor*/1, /*offset*/0,
-						/*vref*/NULL, /*default_label*/pSensor->ssName);
+						/*vref*/NULL, /*default_label*/(gchar *)pSensor->ssName);
 
 		            g_free(id_name);
 		            fanCount++;
@@ -795,11 +833,16 @@ gkrellm_sys_sensors_sf_init(void)
 	hData = gkrellm_sys_sensors_open_shm_helper(SPEEDFAN_SHM_NAME, SPEEDFAN_EXE_NAME);
 	if (hData == 0)
 		return FALSE;
+
+	gkrellm_debug(DEBUG_SYSDEP, "Mapping SpeedFan SHM file\n");
 	pData = (SFSharedMemory *)MapViewOfFile(hData, FILE_MAP_READ, 0, 0, 0);
 	if (pData != NULL)
 		{
 		ret = TRUE; // Mark SpeedFan as available
 
+		gkrellm_debug(DEBUG_SYSDEP, "Enumerating %hu temps, %hu voltages and %hu fans\n",
+					pData->NumTemps, pData->NumVolts, pData->NumFans);
+
 		for (i = 0; i < pData->NumTemps; i++)
 			{
 			id_name = g_strdup_printf("speedfan-temp-%d", i);
@@ -934,6 +977,7 @@ gkrellm_sys_sensors_ct_init(void)
 	hData = gkrellm_sys_sensors_open_shm_helper(CORE_TEMP_SHM_NAME, CORE_TEMP_EXE_NAME);
 	if (hData == 0)
 		return FALSE;
+	gkrellm_debug(DEBUG_SYSDEP, "Mapping CoreTemp SHM file\n");
 	pData = (CORE_TEMP_SHARED_DATA *)MapViewOfFile(hData, FILE_MAP_READ, 0, 0, 0);
 	if (pData != NULL)
 		{
@@ -1012,6 +1056,7 @@ gkrellm_sys_sensors_init(void)
 	init_ok |= gkrellm_sys_sensors_ct_init();
 	init_ok |= gkrellm_sys_sensors_mbm_init();
 
+	gkrellm_debug(DEBUG_SYSDEP, "INIT sensors finished, result is %d\n", init_ok);
 	// returns true if at least one sensors interface has been found
 	return init_ok;
 	}
@@ -1232,7 +1277,7 @@ gkrellm_sys_net_init(void)
 	add_counter_list(
 			  510 // object_index
 			, 264 // counter_index1
-			, 896 // counter_index2
+			, 506 // counter_index2
 			, gkrellm_sys_net_add_cb);
 
 	gkrellm_debug(DEBUG_SYSDEP, "Found %i network adapters for monitoring.\n",
@@ -1295,7 +1340,7 @@ gchar *gkrellm_sys_disk_name_from_device(gint device_number, gint unit_number,
 	return name;
 }
 
-gint gkrellm_sys_disk_order_from_name(gchar *name)
+gint gkrellm_sys_disk_order_from_name(const gchar *name)
 {
 	return 0; // Disk by name not implemented in Windows
 }
@@ -1400,7 +1445,7 @@ gkrellm_sys_disk_cleanup(void)
 static PDH_HCOUNTER processCounter = NULL;
 static PDH_HCOUNTER waitQueueCounter = NULL;
 // Library handle for secur32.dll, lib is loaded at runtime
-static HANDLE hSecur32 = NULL;
+static HINSTANCE hSecur32 = NULL;
 // Function pointers to various functions from secur32.dll
 static pfLsaEnumerateLogonSessions pfLELS = NULL;
 static pfLsaFreeReturnBuffer pfLFRB = NULL;
@@ -1478,6 +1523,37 @@ gkrellm_sys_proc_read_users(void)
 	gint i;
 	// Number of interactive users
 	gint n_users = 0;
+
+#if _WIN32_WINNT >= 0x501 // Windows XP or newer
+	BOOL ret;
+	WTS_SESSION_INFOW *pSessionList = NULL;
+	DWORD sessionListCount = 0;
+	WTS_SESSION_INFOW *pSession = NULL;
+
+	gkrellm_debug(DEBUG_SYSDEP, "Enumerating terminal sessions...\n");
+	// Returns list of terminal sessions in pSessionInfo[]
+	ret = WTSEnumerateSessionsW(WTS_CURRENT_SERVER_HANDLE, 0, 1, &pSessionList,
+			&sessionListCount);
+	if (!ret)
+		{
+		win32_warning(WTSAPI32,
+				GetLastError(),
+				"Enumerating terminal sessions failed");
+		}
+	else if (pSessionList != NULL)
+		{
+		gkrellm_debug(DEBUG_SYSDEP, "Found %d terminal sessions\n", sessionListCount);
+		for (i = 0; i < sessionListCount; i++)
+			{
+			pSession = &pSessionList[i];
+			gkrellm_debug(DEBUG_SYSDEP, "Session %d (%ls) has state %d\n",
+			    pSession->SessionId, pSession->pWinStationName, pSession->State);
+			if (pSession->State == WTSActive)
+				n_users++;
+			}
+		WTSFreeMemory(pSessionList);
+		}
+#else // TODO: Remove this code-branch if nobody wants win2k-support anymore 
 	// Return value for Lsa functions
 	NTSTATUS ntstatus;
 	// Arguments for LsaEnumerateLogonSessions()
@@ -1557,6 +1633,7 @@ gkrellm_sys_proc_read_users(void)
 
 	// Free LUID list provided by OS, even if function returned an error before
 	pfLFRB(pSessions);
+#endif
 
 	gkrellm_proc_assign_users(n_users);
 	}
@@ -1629,15 +1706,11 @@ gkrellm_sys_proc_init(void)
 		}
 	else
 		{
-		win32_warning(NULL, GetLastError(),
-				"Could not load secur32.dll, number of logged in " \
-				"users will not be detected\n");
+		win32_warning(NULL, GetLastError(), "Could not load secur32.dll\n");
 		}
 
-
 	// Determine OS for proper load-average computation
 	// (wait-queue value on win2k is off by one)
-
 #if 0
 	memset(&vi, 0, sizeof(OSVERSIONINFOEXW));
 	vi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEXW);
@@ -1656,6 +1729,7 @@ gkrellm_sys_proc_init(void)
 static void
 gkrellm_sys_proc_cleanup(void)
 	{
+	gkrellm_debug(DEBUG_SYSDEP, "Cleanup process monitoring\n");
 	// Unload secur32.dll and invalidate function pointers
 	pfLELS = NULL;
 	pfLFRB = NULL;
@@ -1689,9 +1763,11 @@ typedef struct _PERFORMANCE_INFORMATION {
 
 typedef BOOL (WINAPI *pfGetPerformanceInfo)(PERFORMANCE_INFORMATION *, DWORD);
 
-static HINSTANCE psapi_instance = NULL;
+static HINSTANCE hPsapi = NULL;
 static pfGetPerformanceInfo pGPI = NULL;
 static DWORD page_size = 1;
+static HINSTANCE hNtdll = NULL;
+static pfZwQuerySystemInformation pZwQSI = NULL;
 
 void
 gkrellm_sys_mem_read_data(void)
@@ -1750,6 +1826,9 @@ gkrellm_sys_swap_read_data(void)
 	SYSTEM_PAGEFILE_INFORMATION *pInfo;
 	LPVOID pBuf = NULL;
 
+	if (pZwQSI == NULL)
+		return;
+
 	gkrellm_debug(DEBUG_SYSDEP, "Checking swap utilization\n");
 
 	// it is difficult to determine beforehand which size of the
@@ -1760,8 +1839,7 @@ gkrellm_sys_swap_read_data(void)
 	{
 		pBuf = g_malloc(szBuf);
 
-		ntstatus = ZwQuerySystemInformation(SystemPagefileInformation, pBuf,
-			szBuf, NULL);
+		ntstatus = pZwQSI(SystemPagefileInformation, pBuf, szBuf, NULL);
 		if (ntstatus == STATUS_INFO_LENGTH_MISMATCH)
 		{
 			// Buffer was too small, double its size and try again
@@ -1809,14 +1887,15 @@ gkrellm_sys_mem_init(void)
 	GetSystemInfo(&si);
 	page_size = si.dwPageSize;
 
-	psapi_instance = LoadLibraryW(L"PSAPI.DLL");
-	if (psapi_instance)
+	hPsapi = LoadLibraryW(L"psapi.dll");
+	if (hPsapi)
 		{
-		pGPI = GetProcAddress(psapi_instance, "GetPerformanceInfo");
+		gkrellm_debug(DEBUG_SYSDEP, "Loaded psapi.dll\n");
+		pGPI = (pfGetPerformanceInfo)GetProcAddress(hPsapi, "GetPerformanceInfo");
 		if (pGPI == NULL)
 			{
 			gkrellm_debug(DEBUG_SYSDEP, "No GetPerformanceInfo() in " \
-					"PSAPI.DLL, cache-memory will stay at 0!\n");
+					"psapi.dll, cache-memory will stay at 0!\n");
 			}
 		}
 	else
@@ -1824,20 +1903,41 @@ gkrellm_sys_mem_init(void)
 		win32_warning(NULL, GetLastError(), "Could not load PSAPI.DLL");
 		}
 
+	hNtdll = LoadLibraryW(L"ntdll.dll");
+	if (hNtdll)
+		{
+		gkrellm_debug(DEBUG_SYSDEP, "Loaded ntdll.dll\n");
+		pZwQSI = (pfZwQuerySystemInformation)GetProcAddress(hNtdll, "ZwQuerySystemInformation");
+		if (pZwQSI == NULL)
+			{
+			gkrellm_debug(DEBUG_SYSDEP, "No ZwQuerySystemInformation() in " \
+					"ntdll.dll, pagefile-usage cannot be determined.\n");
+			}
+		}
+	else
+		{
+		win32_warning(NULL, GetLastError(), "Could not load ntdll.dll");
+		}
+
 	return TRUE;
 	}
 
 static void
 gkrellm_sys_mem_cleanup(void)
 	{
+	gkrellm_debug(DEBUG_SYSDEP, "Cleanup memory monitoring\n");
 	pGPI = NULL;
-	if (psapi_instance)
-		FreeLibrary(psapi_instance);
-	psapi_instance = NULL;
+	if (hPsapi != NULL)
+		FreeLibrary(hPsapi);
+	hPsapi = NULL;
+	
+	pZwQSI = NULL;
+	if (hNtdll != NULL)
+		FreeLibrary(hNtdll);
+	hNtdll = NULL;
 	}
 
 
-
 /* ===================================================================== */
 /* Battery monitor interface */
 /* ===================================================================== */
@@ -1884,6 +1984,8 @@ gboolean gkrellm_sys_battery_init()
 
 gboolean gkrellm_sys_fs_fstab_modified(void)
 	{
+	/* TODO: determine changes in available volumes on win32 using
+	FindFirstVolume(), FindNextVolume() etc. */
 	return FALSE;
 	}
 
@@ -1947,9 +2049,9 @@ void gkrellm_sys_fs_get_fsusage(gpointer fs, gchar *dir)
 		{
 		// fs, blocks, avail, free, size
 		gkrellm_fs_assign_fsusage_data(fs
-			, EnlargedUnsignedDivide(totalBytes, 1024, 0) /* total */
-			, EnlargedUnsignedDivide(availToCaller, 1024, 0) /* free to caller */
-			, EnlargedUnsignedDivide(freeBytes, 1024, 0) /* free */
+			, totalBytes.QuadPart / (ULONGLONG)1024
+			, availToCaller.QuadPart / (ULONGLONG)1024 /* free to caller */
+			, freeBytes.QuadPart / (ULONGLONG)1024 /* free */
 			, 1024 /* block size */
 			);
 		}
@@ -2041,17 +2143,45 @@ void gkrellm_sys_fs_get_fstab_list(void)
 /* INET monitor interfaces */
 /* ===================================================================== */
 
+// Library handle for Iphlpapi.dll, lib is loaded at runtime
+static HINSTANCE hIphlpapi = NULL;
+// Function pointer to GetTcp6Table() which only exists on Vista and newer
+static GetTcp6TableFunc pfGetTcp6Table = NULL;
+
 gboolean gkrellm_sys_inet_init(void)
-{
-	gkrellm_debug(DEBUG_SYSDEP, "INIT inet port monitoring\n");
-	return TRUE;
-}
-
-
-void gkrellm_sys_inet_read_tcp_data(void)
 	{
-	// TODO: Make use of GetTcp6Table() by loading it at runtime
-	//       (only available on vista and newer)
+	gkrellm_debug(DEBUG_SYSDEP, "INIT inet port monitoring\n");
+	hIphlpapi = LoadLibraryW(L"Iphlpapi.dll");
+	if (hIphlpapi != NULL)
+		{
+		gkrellm_debug(DEBUG_SYSDEP, "Loaded Iphlpapi.dll\n");
+		pfGetTcp6Table = (GetTcp6TableFunc) GetProcAddress(hIphlpapi,
+			"GetTcp6Table");
+		if (pfGetTcp6Table == NULL)
+			{
+			g_warning("Could not get address for " \
+				"GetTcp6Table() in Iphlpapi.dll " \
+				"(this is ok on windows versions older than vista)\n");
+			}
+		}
+	else
+		{
+		win32_warning(NULL, GetLastError(), "Could not load Iphlpapi.dll\n");
+		}
+	return TRUE;
+	}
+static void
+gkrellm_sys_inet_cleanup(void)
+	{
+	gkrellm_debug(DEBUG_SYSDEP, "Cleanup inet port monitoring\n");
+	pfGetTcp6Table = NULL;
+	if (hIphlpapi != NULL)
+		FreeLibrary(hIphlpapi);
+	hIphlpapi = NULL;
+	}
+
+static void win32_read_tcp_data(void)
+	{
 	PMIB_TCPTABLE pTcpTable = NULL;
 	DWORD dwTableSize = 0;
 	DWORD dwStatus;
@@ -2059,7 +2189,7 @@ void gkrellm_sys_inet_read_tcp_data(void)
 	ActiveTCP tcp;
 	DWORD i;
 
-	gkrellm_debug(DEBUG_SYSDEP, "Fetching list of TCP connections\n");
+	gkrellm_debug(DEBUG_SYSDEP, "Fetching list of IPv4 TCP connections\n");
 
 	// Make an initial call to GetTcpTable to
 	// get the necessary size into the dwSize variable
@@ -2087,7 +2217,7 @@ void gkrellm_sys_inet_read_tcp_data(void)
 				tcp.local_port         = htons(tcprow->dwLocalPort);
 				tcp.remote_addr.s_addr = tcprow->dwRemoteAddr;
 #if defined(INET6)
-				tcp.in6_addr = 0;
+				memset(&tcp.remote_addr6, 0, sizeof(struct in6_addr));
 #endif
 				tcp.remote_port        = htons(tcprow->dwRemotePort);
 				tcp.is_udp             = FALSE;
@@ -2098,7 +2228,7 @@ void gkrellm_sys_inet_read_tcp_data(void)
 			else
 			{
 				win32_warning(NULL, dwStatus,
-					"Could not fetch list of TCP connections");
+					"Could not fetch list of IPv4 TCP connections");
 			}
 
 		g_free(pTcpTable);
@@ -2106,10 +2236,81 @@ void gkrellm_sys_inet_read_tcp_data(void)
 		else
 		{
 			win32_warning(NULL, dwStatus,
-					"Could not fetch list of TCP connections");
+					"Could not fetch list of IPv4 TCP connections");
 		}
 	}
 
+#if defined(INET6)
+static void win32_read_tcp6_data(void)
+	{
+	PMIB_TCP6TABLE pTcpTable = NULL;
+	DWORD dwTableSize = 0;
+	DWORD dwStatus;
+	MIB_TCP6ROW *tcprow;
+	ActiveTCP tcp;
+	DWORD i;
+
+	if (pfGetTcp6Table == NULL)
+		return; // missing GetTcp6Table() on this machine
+
+	gkrellm_debug(DEBUG_SYSDEP, "Fetching list of IPv6 TCP connections\n");
+
+	// Make an initial call to GetTcpTable to
+	// get the necessary size into the dwSize variable
+	dwStatus = pfGetTcp6Table(NULL, &dwTableSize, FALSE);
+
+	if ((dwStatus == ERROR_INSUFFICIENT_BUFFER) && (dwTableSize > 0))
+		{
+		pTcpTable = (MIB_TCP6TABLE *)g_malloc(dwTableSize);
+
+		// Make a second call to GetTcpTable to get
+		// the actual data we require
+		dwStatus = pfGetTcp6Table(pTcpTable, &dwTableSize, FALSE);
+
+		if (dwStatus == NO_ERROR)
+			{
+			for (i = 0; i < pTcpTable->dwNumEntries; i++)
+				{
+				tcprow = &pTcpTable->table[i];
+
+				// Skip connections that are not fully established
+				if (tcprow->dwState != MIB_TCP_STATE_ESTAB)
+					continue;
+
+				tcp.family             = AF_INET6;
+				tcp.local_port         = htons(tcprow->dwLocalPort);
+				tcp.remote_addr.s_addr = 0;
+				tcp.remote_addr6       = tcprow->RemoteAddr;
+				tcp.remote_port        = htons(tcprow->dwRemotePort);
+				tcp.is_udp             = FALSE;
+
+				gkrellm_inet_log_tcp_port_data(&tcp);
+				}
+			}
+			else
+			{
+				win32_warning(NULL, dwStatus,
+					"Could not fetch list of IPv6 TCP connections");
+			}
+
+		g_free(pTcpTable);
+		}
+		else
+		{
+			win32_warning(NULL, dwStatus,
+					"Could not fetch list of IPv6 TCP connections");
+		}
+		}
+#endif
+
+void gkrellm_sys_inet_read_tcp_data(void)
+	{
+	win32_read_tcp_data();
+#if defined(INET6)
+	win32_read_tcp6_data();
+#endif
+	}
+
 
 /* ===================================================================== */
 /* Uptime monitor interface */
