@@ -1,7 +1,9 @@
 /* GKrellM
-|  Copyright (C) 1999-2009 Bill Wilson
+|  Copyright (C) 1999-2010 Bill Wilson
+|                2007-2010 Stefan Gehn
 |
-|  Author:  Bill Wilson    billw@gkrellm.net
+|  Authors:  Bill Wilson    billw@gkrellm.net
+|            Stefan Gehn    stefan+gkrellm@srcbox.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |
@@ -82,7 +84,7 @@ void win32_init_callbacks(void)
     gkrellm_callbacks.gkrellm_add_chartdata = gkrellm_add_chartdata;
     gkrellm_callbacks.gkrellm_add_default_chartdata = gkrellm_add_default_chartdata;
     gkrellm_callbacks.gkrellm_alloc_chartdata = gkrellm_alloc_chartdata;
-    gkrellm_callbacks.gkrellm_store_chartdata = gkrellm_store_chartdata;
+    gkrellm_callbacks.gkrellm_store_chartdatav = gkrellm_store_chartdatav;
     gkrellm_callbacks.gkrellm_draw_chartdata = gkrellm_draw_chartdata;
     gkrellm_callbacks.gkrellm_monotonic_chartdata = gkrellm_monotonic_chartdata;
     gkrellm_callbacks.gkrellm_get_chartdata_hide = gkrellm_get_chartdata_hide;
@@ -447,5 +449,11 @@ void win32_init_callbacks(void)
     gkrellm_callbacks.gkrellm_gdk_text_markup_width = gkrellm_gdk_text_markup_width;
     gkrellm_callbacks.gkrellm_gdk_draw_string_markup = gkrellm_gdk_draw_string_markup;
     gkrellm_callbacks.gkrellm_gdk_draw_text_markup = gkrellm_gdk_draw_text_markup;
+
+    //---------------------------------------------------------------------------
+    // new since 2.3.2
+
+    gkrellm_callbacks.gkrellm_debugv = gkrellm_debugv;
+
 } // win32_init_callbacks()
 
