@@ -1,8 +1,10 @@
  /* GKrellM Windows Portion
 |  Copyright (C) 2002 Bill Nalen
+|                2007-2010 Stefan Gehn
 |
-|  Author:  Bill Nalen    bill@nalens.com
-|  Latest versions might be found at:  http://bill.nalens.com
+|  Authors:  Bill Nalen     bill@nalens.com
+|            Stefan Gehn    stefan+gkrellm@srcbox.net
+|  Latest versions might be found at:  http://gkrellm.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -82,7 +84,8 @@ typedef struct
 					    GdkPixmap *, gchar *);
     GkrellmChartdata *(*gkrellm_add_default_chartdata)(GkrellmChart *, gchar *);
     void		(*gkrellm_alloc_chartdata)(GkrellmChart *);
-    void		(*gkrellm_store_chartdata)(GkrellmChart *, gulong, ...);
+    // gkrellm_store_chartdata is not called from libgkrellm, only gkrellm_store_chartdatav
+    void		(*gkrellm_store_chartdatav)(GkrellmChart *, gulong, va_list args);
     void		(*gkrellm_draw_chartdata)(GkrellmChart *);
     void		(*gkrellm_monotonic_chartdata)(GkrellmChartdata *, gboolean);
     gboolean	(*gkrellm_get_chartdata_hide)(GkrellmChartdata *);
@@ -576,6 +579,11 @@ typedef struct
   void          (*gkrellm_gdk_draw_string_markup)(GdkDrawable *drawable, PangoFontDescription *font, GdkGC *gc, gint x, gint y, gchar *string);
   void          (*gkrellm_gdk_draw_text_markup)(GdkDrawable *drawable, PangoFontDescription *font, GdkGC *gc, gint x, gint y, gchar *string, gint len);
 
+  //---------------------------------------------------------------------------
+  // new since 2.3.2
+
+  // gkrellm_debug is not called from libgkrellm, only gkrellm_debugv
+  void (*gkrellm_debugv)(guint debug_level, const gchar *format, va_list arg);
 
 } win32_plugin_callbacks;
 
